@@ -11,9 +11,17 @@ namespace osl
   {
     struct EnterKing
     {
-      static bool canDeclareWin(const NumEffectState& state);
+      static bool
+#ifdef __GNUC__
+	__attribute__ ((pure))
+#endif
+      canDeclareWin(const NumEffectState& state);
       template <Player P>
-      static bool canDeclareWin(const NumEffectState& state);
+      static bool
+#ifdef __GNUC__
+	__attribute__ ((pure))
+#endif
+      canDeclareWin(const NumEffectState& state);
     };
 
   } // namespace enter_king
