@@ -14,6 +14,7 @@
 #include "osl/progress/effect5x3.h"
 #include "osl/progress/ml/newProgress.h"
 #include "osl/container/tripleInt.h"
+#include "osl/oslConfig.h"
 
 #define USE_TEST_PROGRESS
 // NewProgressが学習可能な場合に定義 (現在はosl側に変更はないので常に定義)
@@ -92,7 +93,7 @@ namespace osl
 	MultiInt rook_promote_defense;
 	MultiInt piece_stand_combination, piece_stand_y, knight_check,
 	  knight_head, pawn_ptypeo, ptype_count_value, lance_effect_piece,
-	  ptype_y_pawn_y, bishop_and_king;
+	  ptype_y_pawn_y, bishop_and_king, rook_silver_knight, bishop_silver_knight;
 	CArray<BoardMask, 2> knight_fork_squares;
 	CArray<PieceMask, 2> effect25; // index: owner of king
 	CArray<PieceMask, 2> effect25_supported; // index: owner of king
@@ -166,7 +167,7 @@ namespace osl
 	  }
 	}
       public:
-	OpenMidEndingEval(const NumEffectState &state);
+	explicit OpenMidEndingEval(const NumEffectState &state, bool limit_progress_independent_value=! OslConfig::hasByoyomi());
 	void changeTurn() { }
 	static bool initialized()
 	{
@@ -174,6 +175,7 @@ namespace osl
 	}
 	static bool setUp(const char *filename);
 	static bool setUp();
+	static std::string defaultFilename();
 	int progressIndependentValue() const 
 	{
 	  return progress_independent_value + recalculated_value + piece_pair_value
@@ -194,7 +196,8 @@ namespace osl
 	    ptype_yy + king3pieces + bishop_head + knight_head
 	    + rook_promote_defense +
 	    ptype_count_value + lance_effect_piece + ptype_y_pawn_y +
-	    bishop_and_king + piece_fork_turn[turn] + recalculated_stage_value;
+	    bishop_and_king + piece_fork_turn[turn] + rook_silver_knight + bishop_silver_knight +
+	    recalculated_stage_value;
 	}
 	int openingValue() const 
 	{
@@ -230,6 +233,8 @@ namespace osl
 		  ptype_y_pawn_y[0] +
 		  bishop_and_king[0] +
 		  piece_fork_turn[turn][0] +
+		  rook_silver_knight[0] +
+		  bishop_silver_knight[0] +
 		  recalculated_stage_value[0]);
 	}
 	int midgameValue() const 
@@ -266,6 +271,8 @@ namespace osl
 		  ptype_y_pawn_y[1] +
 		  bishop_and_king[1] +
 		  piece_fork_turn[turn][1] +
+		  rook_silver_knight[1] +
+		  bishop_silver_knight[1] +
 		  recalculated_stage_value[1]);
 	}
 	int midgame2Value() const 
@@ -302,6 +309,8 @@ namespace osl
 		  ptype_y_pawn_y[2] +
 		  bishop_and_king[2] +
 		  piece_fork_turn[turn][2] +
+		  rook_silver_knight[2] +
+		  bishop_silver_knight[2] +
 		  recalculated_stage_value[2]);
 	}
 	int endgameValue() const 
@@ -338,6 +347,8 @@ namespace osl
 		  ptype_y_pawn_y[EndgameIndex] +
 		  bishop_and_king[EndgameIndex] +
 		  piece_fork_turn[turn][EndgameIndex] +
+		  rook_silver_knight[EndgameIndex] +
+		  bishop_silver_knight[EndgameIndex] +
 		  recalculated_stage_value[EndgameIndex]);
 	}
 	void invalidateCache() { cache=INVALID; }
@@ -387,8 +398,10 @@ namespace osl
 	  const int w2 = progress_max - c1;
 #endif
 	  assert(c0 == w2);
-	  int progress_independent = progressIndependentValueAdjusted
-	    (progressIndependentValue(), progress, progress_max);
+	  int progress_independent = use_progress_independent_value_limit
+	    ? progressIndependentValueAdjusted
+	    (progressIndependentValue(), progress, progress_max)
+	    : progressIndependentValue();
 	  int sum = progress_independent * c0;
 	  const MultiInt stage_sum = stageValue();
 	  if (progress < c0) 
@@ -506,7 +519,14 @@ namespace osl
 
 	OpenMidEndingEvalDebugInfo debugInfo(const NumEffectState &state);
 	static void setRandom();
-	static const OpenMidEndingPtypeTable Piece_Value;
+	static void resetWeights(const int *w, size_t length);
+	static OpenMidEndingPtypeTable Piece_Value;
+	bool progressIndependentValueLimit() const {
+	  return use_progress_independent_value_limit;
+	}
+      private:
+	template <class Reader>
+	static void doResetWeights(Reader& reader);
       };
     }
   }
