@@ -40,6 +40,9 @@ namespace osl
     static void setNumCPUs(int ncpu);
     static int numCPUs();
 
+    static int dfpnMaxDepth();
+    static void setDfpnMaxDepth(int);
+
     static bool usiMode();
     static void setUsiMode(bool enable=true);
     static bool usiModeInSilent();
@@ -98,6 +101,8 @@ namespace osl
     static void setUp();
     static bool hasByoyomi();
     static void setHasByoyomi(bool);
+
+    static bool healthCheck();
   private:
     static const std::string makeHome();
     static const std::string makeTest();
@@ -118,6 +123,7 @@ namespace osl
     static volatile bool force_root_window;
     static volatile int root_window_alpha, root_window_beta;
     static volatile int in_unit_test;
+    static int dfpn_max_depth;
   public:
     static boost::mutex lock_io;
   };
