@@ -1,7 +1,7 @@
 /* pieceTable.h
  */
-#ifndef _PIECE_TABLE_H
-#define _PIECE_TABLE_H
+#ifndef OSL_PIECE_TABLE_H
+#define OSL_PIECE_TABLE_H
 
 #include "osl/piece.h"
 #include "osl/misc/carray.h"
@@ -27,7 +27,7 @@ namespace osl
   extern const PieceTable Piece_Table;
 }
 
-#endif /* _PIECE_TABLE_H */
+#endif /* OSL_PIECE_TABLE_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
