@@ -77,7 +77,7 @@ NumSimpleEffectTable::copyFrom(const NumSimpleEffectTable& src)
   }
 #else
   for(int i=0;i<40;i++)
-    (*this).effectedNumTable[i]=(*src).effectNumTable[i];
+    (*this).effectedNumTable[i]=src.effectedNumTable[i];
 #endif
 
 #if defined(i386) || defined(__x86_64)
@@ -193,7 +193,7 @@ NumSimpleEffectTable::copyFrom(const NumSimpleEffectTable& src)
 #else
   for(int x=1;x<=9;x++)
     for(int y=1;y<=9;y++)
-      this->effects[Square(x,y).index()]=src->effects[Square(x,y).index()];
+      this->effects[Square(x,y).index()]=src.effects[Square(x,y).index()];
 #endif
 }
 
