@@ -272,23 +272,20 @@ PawnAdvanceAll::evalWithUpdateBang(const osl::state::NumEffectState &state,
   {
     const Piece piece = state.pieceAt(
       moved.to() + DirectionPlayerTraits<D, Opponent>::offset());
-    if (piece.isOnBoardByOwner<Opponent>() &&
-	piece.ptype() == PAWN)
+    if (piece.isPlayerPtype(Opponent,PAWN))
       adjust<P>(index(Opponent, piece.square()), values);
   }
   if (!moved.isDrop())
   {
     const Piece piece = state.pieceAt(
       moved.from() + DirectionPlayerTraits<D, P>::offset());
-    if (piece.isOnBoardByOwner<P>() &&
-	piece.ptype() == PAWN)
+    if (piece.isPlayerPtype(P,PAWN))
       adjust<Opponent>(index(P, piece.square()), values);
   }
   {
     const Piece piece = state.pieceAt(
       moved.to()+DirectionPlayerTraits<D,P>::offset());
-    if (piece.isOnBoardByOwner<P>() &&
-	piece.ptype() == PAWN)
+    if (piece.isPlayerPtype(P,PAWN))
       adjust<P>(index(P, piece.square()), values);
   }
 }
@@ -1396,15 +1393,15 @@ KnightHead::eval(const NumEffectState &state)
     if (knight.isOnBoard() && !knight.isPromoted())
     {
       const Square up = Board_Table.nextSquare(knight.owner(),
-						   knight.square(), U);
+					       knight.square(), U);
       const Piece up_piece = state.pieceAt(up);
-      if ((up_piece.isEmpty() && state.hasPieceOnStand<PAWN>(knight.owner()) &&
-	   !state.isPawnMaskSet(knight.owner(), knight.square().x()) &&
-	   state.countEffect(knight.owner(), up) >=
+      if ((up_piece.isEmpty() && state.hasPieceOnStand<PAWN>(alt(knight.owner())) &&
+	   !state.isPawnMaskSet(alt(knight.owner()), knight.square().x()) &&
+	   state.countEffect(knight.owner(), up) <=
 	   state.countEffect(alt(knight.owner()), up)) ||
-	  (state.hasEffectByPtypeStrict<PAWN>(knight.owner(), up) &&
-	   (up_piece.isEmpty() || up_piece.owner() != knight.owner()) &&
-	   state.countEffect(knight.owner(), up) >
+	  (state.hasEffectByPtypeStrict<PAWN>(alt(knight.owner()), up) &&
+	   (up_piece.isEmpty() || up_piece.owner() == knight.owner()) &&
+	   state.countEffect(knight.owner(), up) <
 	   state.countEffect(alt(knight.owner()), up)))
       {
 	const int y = knight.square().y();
