@@ -60,12 +60,11 @@ namespace
     Eval::setUp(weights, stage);
   }
 #endif
-  typedef osl::misc::BinaryElementReader<int> reader_t;
-  template <class Eval>
-  static int setUpOne(reader_t& p)
+  template <class Eval, class Reader>
+  static int setUpOneWithDim(Reader& p, int dim)
   {
-    osl::eval::ml::Weights weights(Eval::DIM);
-    // std::cerr << typeid(Eval).name() << " " << Eval::DIM << "\n";
+    osl::eval::ml::Weights weights(dim);
+    // std::cerr << typeid(Eval).name() << " " << dim << "\n";
     for (size_t i = 0; i < weights.dimension(); ++i)
     {
       if (! p.hasNext())
@@ -76,8 +75,13 @@ namespace
     Eval::setUp(weights);
     return weights.dimension();
   }
-  template <class Eval>
-  static int setUpOne(reader_t& p, int stage)
+  template <class Eval, class Reader>
+  static int setUpOne(Reader& p)
+  {
+    return setUpOneWithDim<Eval>(p, Eval::DIM);
+  }
+  template <class Eval, class Reader>
+  static int setUpOne(Reader& p, int stage)
   {
     osl::eval::ml::Weights weights(Eval::DIM);
     // std::cerr << typeid(Eval).name() << " " << Eval::DIM << "\n";
@@ -93,30 +97,68 @@ namespace
   }
 }
 
+namespace osl
+{
+  struct IntArrayReader
+  {
+    size_t cur, length;
+    const int *array;
+    IntArrayReader(const int *a, size_t l) : cur(0), length(l), array(a)
+    {
+    }
+    bool hasNext() const { return cur < length; }
+    bool failed() const { return false; }
+    int read() { return array[cur++]; }
+  };
+}
+
+void osl::eval::ml::
+OpenMidEndingEval::resetWeights(const int *w, size_t length)
+{
+  IntArrayReader reader(w, length);
+  doResetWeights(reader);
+}
+
 bool osl::eval::ml::OpenMidEndingEval::setUp(const char *filename)
 {
+  boost::mutex::scoped_lock lk(initialize_mutex);
   if (initialized_flag == Loaded)
     return true;
-  boost::mutex::scoped_lock lk(initialize_mutex);
-  std::ifstream is(filename);
+  typedef osl::misc::BinaryElementReader<int> reader_t;
+  std::ifstream is(filename, std::ios_base::binary);
   reader_t reader(is);
   if (! reader.hasNext()) {
     initialized_flag = Zero;
     return false;
   }
-  Weights weights(PTYPE_SIZE);
+  doResetWeights(reader);
+  return initialized_flag == Loaded;
+}
+
+template <class Reader>
+void osl::eval::ml::
+OpenMidEndingEval::doResetWeights(Reader& reader)
+{
   size_t read_count = 0;
 
   // flat
+  CArray<int, PTYPE_SIZE> piece_values = {{0}};
+  Weights weights(PTYPE_SIZE);
   for (int i = 0; i < PTYPE_SIZE; ++i)
   {
     if (! reader.hasNext())
       break;
     int val = reader.read();
+    if (i == KING) {
+      assert(val == 0);
+      val = PtypeEvalTraits<KING>::val;
+    }
     weights.setValue(i, val);
+    piece_values[i] = val;
     ++read_count;
   }
   PieceEval::setUp(weights);
+  Piece_Value.reset(piece_values);
 
   PiecePair::init();
   piece_pair_weights.resetDimension(PiecePair::DIM);
@@ -346,6 +388,9 @@ bool osl::eval::ml::OpenMidEndingEval::setUp(const char *filename)
   read_count += setUpOne<NonPawnAttackedPtypePair>(reader);
   read_count += setUpOne<MajorCheckWithCapture>(reader);
   read_count += setUpOne<SilverAdvance26>(reader);
+  read_count += setUpOne<RookSilverKnight>(reader);
+  read_count += setUpOne<BishopSilverKnight>(reader);
+  read_count += setUpOne<AttackMajorsInBase>(reader);
 
   initialized_flag = reader.failed() ? Zero : Loaded;
   if (initialized_flag != Loaded)
@@ -353,19 +398,23 @@ bool osl::eval::ml::OpenMidEndingEval::setUp(const char *filename)
     std::cerr << "Failed to load OpenMidEndingEval data "
 	      << ' ' << read_count << std::endl;
   }
-  return initialized_flag == Loaded;
+}
+
+std::string osl::eval::ml::OpenMidEndingEval::defaultFilename()
+{
+  std::string filename = OslConfig::home();
+  filename += "/data/eval.bin";
+  return filename;
 }
 
 bool osl::eval::ml::OpenMidEndingEval::setUp()
 {
-  std::string filename = OslConfig::home();
-  filename += "/data/eval.bin";
-  return setUp(filename.c_str());  
+  return setUp(defaultFilename().c_str());  
 }
 
 osl::eval::ml::
-OpenMidEndingEval::OpenMidEndingEval(const NumEffectState &state)
-  : progress(state), use_progress_independent_value_limit(! OslConfig::hasByoyomi())
+OpenMidEndingEval::OpenMidEndingEval(const NumEffectState &state, bool use_limit)
+  : progress(state), use_progress_independent_value_limit(use_limit)
 {
   assert(initialized_flag != Zero);
   
@@ -584,6 +633,9 @@ OpenMidEndingEval::OpenMidEndingEval(const NumEffectState &state)
   recalculated_stage_value += RookRookPiece::eval(state);
   recalculated_stage_value += King25EffectCountCombination::eval(state, effect25);
   recalculated_stage_value += NonPawnAttackedPtypePair::eval(state);
+  rook_silver_knight = RookSilverKnight::eval(state);
+  bishop_silver_knight = BishopSilverKnight::eval(state);
+  recalculated_stage_value += AttackMajorsInBase::eval(state);
   piece_fork_turn = SilverFork::eval(state, silver_drop);
   piece_fork_turn += BishopRookFork::eval(state, bishop_drop, rook_drop);
   piece_fork_turn += KnightFork::eval(state, knight_fork_squares, knight_drop);
@@ -679,8 +731,8 @@ OpenMidEndingEval::updateSub(const NumEffectState &new_state, Move last_move)
       }
     }
   }
+  const Ptype base_ptype = unpromote(last_move.ptype());
   {
-    const Ptype base_ptype = unpromote(last_move.ptype());
     if (base_ptype == GOLD || base_ptype == SILVER)
     {
       if (!last_move.isDrop())
@@ -945,6 +997,25 @@ OpenMidEndingEval::updateSub(const NumEffectState &new_state, Move last_move)
   recalculated_stage_value += BishopStandFile5::eval(new_state);
   recalculated_stage_value += MajorCheckWithCapture::eval(new_state);
   recalculated_stage_value += SilverAdvance26::eval(new_state);
+  if (base_ptype == ROOK || last_move.ptype() == SILVER ||
+      last_move.ptype() == KNIGHT ||
+      captured == ROOK || captured == PROOK || captured == SILVER ||
+      captured == KNIGHT ||
+      (last_move.isPromotion() &&
+       (base_ptype == SILVER || base_ptype == KNIGHT)))
+  {
+    rook_silver_knight = RookSilverKnight::eval(new_state);
+  }
+  if (base_ptype == BISHOP || last_move.ptype() == SILVER ||
+      last_move.ptype() == KNIGHT ||
+      captured == BISHOP || captured == PBISHOP || captured == SILVER ||
+      captured == KNIGHT ||
+      (last_move.isPromotion() &&
+       (base_ptype == SILVER || base_ptype == KNIGHT)))
+  {
+    bishop_silver_knight = BishopSilverKnight::eval(new_state);
+  }
+  recalculated_stage_value += AttackMajorsInBase::eval(new_state);
 #ifdef USE_TEST_PROGRESS
   recalculated_stage_value += progress.rawData().non_pawn_ptype_attacked_pair_eval[BLACK]
     + progress.rawData().non_pawn_ptype_attacked_pair_eval[WHITE];
@@ -1270,7 +1341,8 @@ setRandom()
   setRandomOne<KingMobility>();
   setRandomOne<KingMobilitySum>();
   setRandomOne<MajorCheckWithCapture>();
-
+  setRandomOne<RookSilverKnight>();
+  setRandomOne<BishopSilverKnight>();
 }
 #endif
 
