@@ -4,7 +4,7 @@
 #include "osl/container/pieceValues.h"
 #include "osl/state/numEffectState.h"
 #include "osl/oslConfig.h"
-#include <boost/filesystem.hpp>
+#include <boost/filesystem/operations.hpp>
 #include <iostream>
 #include <cstdio>
 
