@@ -8,7 +8,7 @@ void
 osl::move_generator::GenerateAttackToPinned::
 generate(Player player, const NumEffectState& state,
 	 move_action::Store& store){
-  assert(state.getTurn()==player);
+  assert(state.turn()==player);
   if(player==BLACK)
     AttackToPinned<BLACK>::generate(state,store);
   else
