@@ -9,10 +9,10 @@ namespace osl
   // explicit template instantiation
   template void move_generator::GenerateOpen::generate
   (Player, const NumEffectState&, Piece, move_action::Store&,
-   Position, Direction);
+   Square, Direction);
 
-  template void move_generator::Open<move_action::Store>::generate<BLACK>(NumEffectState const&, Piece, move_action::Store&, Position, Direction);
-  template void move_generator::Open<move_action::Store>::generate<WHITE>(NumEffectState const&, Piece, move_action::Store&, Position, Direction);
+  template void move_generator::Open<move_action::Store>::generate<BLACK>(NumEffectState const&, Piece, move_action::Store&, Square, Direction);
+  template void move_generator::Open<move_action::Store>::generate<WHITE>(NumEffectState const&, Piece, move_action::Store&, Square, Direction);
 }
 
 // ;;; Local Variables:
