@@ -5,9 +5,9 @@
 #include "osl/misc/ncores.h"
 #include "osl/eval/ml/openMidEndingEval.h"
 #include "osl/progress/ml/newProgress.h"
-#include <map>
 #include <boost/filesystem/operations.hpp>
 #include <boost/static_assert.hpp>
+#include <map>
 #include <limits>
 #include <iostream>
 #include <fstream>
@@ -54,6 +54,7 @@ int osl::OslConfig::usi_output_pawn_value = 100;
 volatile int osl::OslConfig::root_window_alpha = 0; 
 volatile int osl::OslConfig::root_window_beta = 0; 
 volatile int osl::OslConfig::in_unit_test = 0;
+int osl::OslConfig::dfpn_max_depth = 256;
 bool osl::OslConfig::search_exact_value_in_one_reply = false;
 bool osl::OslConfig::has_byoyomi = false;
 boost::mutex osl::OslConfig::lock_io;
@@ -425,6 +426,49 @@ void osl::OslConfig::setUp()
 }
 #endif
 
+bool osl::OslConfig::healthCheck()
+{
+  bool old_verbose = verbose();
+  setVerbose(true);
+  std::cerr << "health check\n";
+  showOslHome(home());
+#ifndef DFPNSTATONE
+  {
+    std::string filename = eval::ml::OpenMidEndingEval::defaultFilename();
+    std::cerr << "loading " << filename << ' ';
+    bool success = eval::ml::OpenMidEndingEval::setUp(filename.c_str());
+    std::cerr << (success ? "success" : "failed\a") << "\n";
+    if (! success) {
+      std::cerr << "exists?  " << boost::filesystem::exists(filename.c_str()) << "\n";
+      std::cerr << "regular? " << boost::filesystem::is_regular_file(filename.c_str()) << "\n";
+      return false;
+    }
+  }
+  {
+    std::string filename = progress::ml::NewProgress::defaultFilename();
+    std::cerr << "loading " << filename << ' ';
+    bool success = progress::ml::NewProgress::setUp(filename.c_str());
+    std::cerr << (success ? "success" : "failed\a") << "\n";
+    if (! success) {
+      std::cerr << "exists?  " << boost::filesystem::exists(filename.c_str()) << "\n";
+      std::cerr << "regular? " << boost::filesystem::is_regular_file(filename.c_str()) << "\n";
+      return false;
+    }
+  }
+#endif
+  setVerbose(old_verbose);
+  return true;
+}
+
+int osl::OslConfig::dfpnMaxDepth()
+{
+  return dfpn_max_depth;
+}
+void osl::OslConfig::setDfpnMaxDepth(int new_depth)
+{
+  dfpn_max_depth = new_depth;
+}
+
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
 // ;;; mode:c++
