@@ -248,10 +248,15 @@ bool osl::progress::ml::NewProgress::setUp(const char *filename)
 }
 
 bool osl::progress::ml::NewProgress::setUp()
+{
+  return setUp(defaultFilename().c_str());  
+}
+
+std::string osl::progress::ml::NewProgress::defaultFilename()
 {
   std::string filename = OslConfig::home();
   filename += "/data/progress.txt";
-  return setUp(filename.c_str());  
+  return filename;
 }
 
 template <osl::Player P>
