@@ -2,6 +2,10 @@
 #include "osl/record/csaIOError.h"
 #include "osl/state/simpleState.h"
 #include "osl/oslConfig.h"
+#include <boost/algorithm/string/classification.hpp>
+#include <boost/algorithm/string/split.hpp>
+#include <boost/algorithm/string/trim.hpp>
+#include <boost/foreach.hpp>
 #include <iostream>
 #include <fstream>
 #include <stdexcept>
@@ -218,7 +222,14 @@ InputStream::load(Record* rec)
     if ((! line.empty())
 	&& (line[line.size()-1] == 13))
       line.erase(line.size()-1);
-    csaParseLine(rv, line, line_parsed, !OslConfig::inUnitTest());
+
+    std::vector<std::string> elements;
+    boost::algorithm::split(elements, line, boost::algorithm::is_any_of(","));
+    BOOST_FOREACH(std::string e, elements) {
+      boost::algorithm::trim(e);
+      boost::algorithm::trim_left(e);
+      csaParseLine(rv, e, line_parsed, !OslConfig::inUnitTest());
+    }
   }
   if (*std::min_element(line_parsed.begin(), line_parsed.end()) == false)
     throw CsaIOError("incomplete position description in csaParseLine");
