@@ -716,7 +716,9 @@ searchAllMoves(SimpleHashRecord *record, Window w)
 #if (defined OSL_SMP) 
   int last_smp_idle = 0;
 #  if (! defined OSL_SMP_NO_SPLIT_INTERNAL)
+#    if (! defined NDEBUG)
   bool already_split = false;
+#    endif
 #  endif
 #endif
 
@@ -802,7 +804,9 @@ searchAllMoves(SimpleHashRecord *record, Window w)
 	if (cur_smp_idle > last_smp_idle) {
 	  last_smp_idle = cur_smp_idle;
 	  assert(! already_split);
+# if (! defined NDEBUG)
 	  already_split = true;
+# endif
 	  if (examineMovesOther<P>(w, best_move, best_value, tried_moves,
 				   alpha_update, last_alpha_update)) {
 	    assert(best_move.validMove());
@@ -824,7 +828,9 @@ searchAllMoves(SimpleHashRecord *record, Window w)
       }
     }
     catch(AlphaBeta2ParallelCommon::SplitFailed&) {
+# if (! defined NDEBUG)
       already_split = false;
+# endif
       // fall through
     }
 #endif
