@@ -113,7 +113,7 @@ namespace osl
   const eval::PtypeEvalTable eval::Ptype_Eval_Table;
   const eval::PtypeEvalTable eval::PieceEval::Piece_Value = eval::Ptype_Eval_Table;
   const eval::PtypeEvalTable eval::ProgressEval::Piece_Value = eval::Ptype_Eval_Table;
-  const eval::ml::OpenMidEndingPtypeTable eval::ml::OpenMidEndingEval::Piece_Value;
+  eval::ml::OpenMidEndingPtypeTable eval::ml::OpenMidEndingEval::Piece_Value;
 #endif
   const hash::HashGenTable hash::Hash_Gen_Table;
   // PtypeTable, BoardTable -> AddEffectTable
