@@ -1,7 +1,6 @@
 #include "osl/effect_util/virtualPin.h"
 #include "osl/record/csaString.h"
 #include "osl/record/csaRecord.h"
-#include "osl/apply_move/applyMove.h"
 #include "osl/oslConfig.h"
 
 #include <cppunit/TestCase.h>
@@ -12,8 +11,6 @@
 using namespace osl;
 using namespace osl::effect_util;
 
-extern bool isShortTest;
-
 class VirtualPinTest : public CppUnit::TestFixture 
 {
   CPPUNIT_TEST_SUITE(VirtualPinTest);
@@ -41,8 +38,8 @@ void VirtualPinTest::testFind()
 			   "P+00FU00FU\n"
 			   "P-00FU\n"
 			   "+\n").getInitialState());
-    CPPUNIT_ASSERT(VirtualPin::find(state, WHITE, Position(5,1)));
-    CPPUNIT_ASSERT(! VirtualPin::find(state, WHITE, Position(7,4)));
+    CPPUNIT_ASSERT(VirtualPin::find(state, WHITE, Square(5,1)));
+    CPPUNIT_ASSERT(! VirtualPin::find(state, WHITE, Square(7,4)));
   }
 }
 
