@@ -12,16 +12,17 @@ class Ki2Test : public CppUnit::TestFixture
 {
   CPPUNIT_TEST_SUITE( Ki2Test );
   CPPUNIT_TEST( testShow );
+  CPPUNIT_TEST( testParseDate );
   CPPUNIT_TEST_SUITE_END();
 public:
   void testShow();
+  void testParseDate();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION( Ki2Test );
 
 using namespace osl;
 using namespace osl::record;
-extern bool isShortTest;
 
 // reference: http://www.shogi.or.jp/faq/kihuhyouki.html
 
@@ -29,7 +30,7 @@ void Ki2Test::testShow()
 {
   {
     const NumEffectState state;
-    const Move move(Position(7,7), Position(7,6), PAWN, 
+    const Move move(Square(7,7), Square(7,6), PAWN, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K6+K_PAWN, 
 			 record::ki2::show(move, state));
@@ -47,41 +48,41 @@ void Ki2Test::testShow()
 			   "P9 *  *  *  *  *  *  *  *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m82u(Position(9,3), Position(8,2), GOLD, 
+    const Move m82u(Square(9,3), Square(8,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m82y(Position(7,2), Position(8,2), GOLD, 
+    const Move m82y(Square(7,2), Square(8,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_GOLD+K_UE, 
 			 record::ki2::show(m82u, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_GOLD+K_YORU, 
 			 record::ki2::show(m82y, state));
-    const Move m52h(Position(5,1), Position(5,2), PPAWN, 
+    const Move m52h(Square(5,1), Square(5,2), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m52u(Position(6,3), Position(5,2), PPAWN, 
+    const Move m52u(Square(6,3), Square(5,2), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_PPAWN+K_HIKU, 
 			 record::ki2::show(m52h, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_PPAWN+K_UE, 
 			 record::ki2::show(m52u, state));
-    const Move m53y(Position(6,3), Position(5,3), PPAWN, 
+    const Move m53y(Square(6,3), Square(5,3), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m53u(Position(5,4), Position(5,3), PPAWN, 
+    const Move m53u(Square(5,4), Square(5,3), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K3+K_PPAWN+K_YORU, 
 			 record::ki2::show(m53y, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K3+K_PPAWN+K_UE, 
 			 record::ki2::show(m53u, state));
-    const Move m76h(Position(6,5), Position(7,6), SILVER, 
+    const Move m76h(Square(6,5), Square(7,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m76u(Position(7,7), Position(7,6), SILVER, 
+    const Move m76u(Square(7,7), Square(7,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K6+K_SILVER+K_HIKU, 
 			 record::ki2::show(m76h, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K6+K_SILVER+K_UE, 
 			 record::ki2::show(m76u, state));
-    const Move m56h(Position(6,5), Position(5,6), SILVER, 
+    const Move m56h(Square(6,5), Square(5,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m56u(Position(4,7), Position(5,6), SILVER, 
+    const Move m56u(Square(4,7), Square(5,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K6+K_SILVER+K_HIKU, 
 			 record::ki2::show(m56h, state));
@@ -101,41 +102,41 @@ void Ki2Test::testShow()
 			   "P9 * +KI+KI *  *  * +GI+GI * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m81l(Position(9,2), Position(8,1), GOLD, 
+    const Move m81l(Square(9,2), Square(8,1), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m81r(Position(7,2), Position(8,1), GOLD, 
+    const Move m81r(Square(7,2), Square(8,1), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K1+K_GOLD+K_HIDARI, 
 			 record::ki2::show(m81l, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K1+K_GOLD+K_MIGI, 
 			 record::ki2::show(m81r, state));
-    const Move m82l(Position(9,2), Position(8,2), GOLD, 
+    const Move m82l(Square(9,2), Square(8,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m82r(Position(7,2), Position(8,2), GOLD, 
+    const Move m82r(Square(7,2), Square(8,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_GOLD+K_HIDARI, 
 			 record::ki2::show(m82l, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_GOLD+K_MIGI, 
 			 record::ki2::show(m82r, state));
-    const Move m56l(Position(6,5), Position(5,6), SILVER, 
+    const Move m56l(Square(6,5), Square(5,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m56r(Position(4,5), Position(5,6), SILVER, 
+    const Move m56r(Square(4,5), Square(5,6), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K6+K_SILVER+K_HIDARI, 
 			 record::ki2::show(m56l, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K6+K_SILVER+K_MIGI, 
 			 record::ki2::show(m56r, state));
-    const Move m78l(Position(8,9), Position(7,8), GOLD, 
+    const Move m78l(Square(8,9), Square(7,8), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m78s(Position(7,9), Position(7,8), GOLD, 
+    const Move m78s(Square(7,9), Square(7,8), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K8+K_GOLD+K_HIDARI, 
 			 record::ki2::show(m78l, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K8+K_GOLD+K_SUGU, 
 			 record::ki2::show(m78s, state));
-    const Move m38s(Position(3,9), Position(3,8), SILVER, 
+    const Move m38s(Square(3,9), Square(3,8), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m38r(Position(2,9), Position(3,8), SILVER, 
+    const Move m38r(Square(2,9), Square(3,8), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R3+K_K8+K_SILVER+K_SUGU, 
 			 record::ki2::show(m38s, state));
@@ -155,11 +156,11 @@ void Ki2Test::testShow()
 			   "P9+TO+TO+TO *  *  * +GI+GI * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m52l(Position(6,3), Position(5,2), GOLD, 
+    const Move m52l(Square(6,3), Square(5,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m52s(Position(5,3), Position(5,2), GOLD, 
+    const Move m52s(Square(5,3), Square(5,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m52r(Position(4,3), Position(5,2), GOLD, 
+    const Move m52r(Square(4,3), Square(5,2), GOLD, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_GOLD+K_HIDARI, 
 			 record::ki2::show(m52l, state));
@@ -167,15 +168,15 @@ void Ki2Test::testShow()
 			 record::ki2::show(m52s, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_GOLD+K_MIGI, 
 			 record::ki2::show(m52r, state));
-    const Move m88r(Position(7,9), Position(8,8), PPAWN, 
+    const Move m88r(Square(7,9), Square(8,8), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m88s(Position(8,9), Position(8,8), PPAWN, 
+    const Move m88s(Square(8,9), Square(8,8), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m88y(Position(9,8), Position(8,8), PPAWN, 
+    const Move m88y(Square(9,8), Square(8,8), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m88h(Position(8,7), Position(8,8), PPAWN, 
+    const Move m88h(Square(8,7), Square(8,8), PPAWN, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m88lu(Position(9,9), Position(8,8), PPAWN, 
+    const Move m88lu(Square(9,9), Square(8,8), PPAWN, 
 		     PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PPAWN+K_MIGI, 
 			 record::ki2::show(m88r, state));
@@ -187,13 +188,13 @@ void Ki2Test::testShow()
 			 record::ki2::show(m88h, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PPAWN+K_HIDARI+K_UE, 
 			 record::ki2::show(m88lu, state));
-    const Move m28s(Position(2,9), Position(2,8), SILVER, 
+    const Move m28s(Square(2,9), Square(2,8), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m28r(Position(1,7), Position(2,8), SILVER, 
+    const Move m28r(Square(1,7), Square(2,8), SILVER, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m28lu(Position(3,9), Position(2,8), SILVER, 
+    const Move m28lu(Square(3,9), Square(2,8), SILVER, 
 		     PTYPE_EMPTY, false, BLACK);
-    const Move m28lh(Position(3,7), Position(2,8), SILVER, 
+    const Move m28lh(Square(3,7), Square(2,8), SILVER, 
 		     PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R2+K_K8+K_SILVER+K_SUGU, 
 			 record::ki2::show(m28s, state));
@@ -217,9 +218,9 @@ void Ki2Test::testShow()
 			   "P9 *  *  *  *  *  *  *  *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m82h(Position(9,1), Position(8,2), PROOK, 
+    const Move m82h(Square(9,1), Square(8,2), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m82u(Position(8,4), Position(8,2), PROOK, 
+    const Move m82u(Square(8,4), Square(8,2), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_PROOK+K_HIKU, 
 			 record::ki2::show(m82h, state));
@@ -239,9 +240,9 @@ void Ki2Test::testShow()
 			   "P9 *  *  *  *  *  * -OU *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m43y(Position(2,3), Position(4,3), PROOK, 
+    const Move m43y(Square(2,3), Square(4,3), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m43h(Position(5,2), Position(4,3), PROOK, 
+    const Move m43h(Square(5,2), Square(4,3), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R4+K_K3+K_PROOK+K_YORU, 
 			 record::ki2::show(m43y, state));
@@ -261,9 +262,9 @@ void Ki2Test::testShow()
 			   "P9 *  *  *  *  *  * -OU *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m43r(Position(2,3), Position(4,3), PROOK, 
+    const Move m43r(Square(2,3), Square(4,3), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m43l(Position(5,3), Position(4,3), PROOK, 
+    const Move m43l(Square(5,3), Square(4,3), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R4+K_K3+K_PROOK+K_MIGI, 
 			 record::ki2::show(m43r, state));
@@ -283,9 +284,9 @@ void Ki2Test::testShow()
 			   "P9+RY+RY *  *  *  * -OU *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m88l(Position(9,9), Position(8,8), PROOK, 
+    const Move m88l(Square(9,9), Square(8,8), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m88r(Position(8,9), Position(8,8), PROOK, 
+    const Move m88r(Square(8,9), Square(8,8), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K8+K_PROOK+K_HIDARI, 
 			 record::ki2::show(m88l, state));
@@ -305,17 +306,17 @@ void Ki2Test::testShow()
 			   "P9 *  *  *  *  *  *  *  * +RY\n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m17l(Position(2,8), Position(1,7), PROOK, 
+    const Move m17l(Square(2,8), Square(1,7), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m17r(Position(1,9), Position(1,7), PROOK, 
+    const Move m17r(Square(1,9), Square(1,7), PROOK, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R1+K_K7+K_PROOK+K_HIDARI, 
 			 record::ki2::show(m17l, state));
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R1+K_K7+K_PROOK+K_MIGI, 
 			 record::ki2::show(m17r, state));
-    const Move m82l(Position(9,1), Position(8,2), PBISHOP, 
+    const Move m82l(Square(9,1), Square(8,2), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m82r(Position(8,1), Position(8,2), PBISHOP, 
+    const Move m82r(Square(8,1), Square(8,2), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K2+K_PBISHOP+K_HIDARI, 
 			 record::ki2::show(m82l, state));
@@ -335,9 +336,9 @@ void Ki2Test::testShow()
 			   "P9 *  *  *  *  *  *  *  *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m85y(Position(9,5), Position(8,5), PBISHOP, 
+    const Move m85y(Square(9,5), Square(8,5), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m85h(Position(6,3), Position(8,5), PBISHOP, 
+    const Move m85h(Square(6,3), Square(8,5), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R8+K_K5+K_PBISHOP+K_YORU, 
 			 record::ki2::show(m85y, state));
@@ -357,9 +358,9 @@ void Ki2Test::testShow()
 			   "P9 *  *  *  *  *  *  *  *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m12h(Position(1,1), Position(1,2), PBISHOP, 
+    const Move m12h(Square(1,1), Square(1,2), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m12u(Position(3,4), Position(1,2), PBISHOP, 
+    const Move m12u(Square(3,4), Square(1,2), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R1+K_K2+K_PBISHOP+K_HIKU, 
 			 record::ki2::show(m12h, state));
@@ -379,9 +380,9 @@ void Ki2Test::testShow()
 			   "P9+UM *  *  * +UM *  *  *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m77l(Position(9,9), Position(7,7), PBISHOP, 
+    const Move m77l(Square(9,9), Square(7,7), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m77r(Position(5,9), Position(7,7), PBISHOP, 
+    const Move m77r(Square(5,9), Square(7,7), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R7+K_K7+K_PBISHOP+K_HIDARI, 
 			 record::ki2::show(m77l, state));
@@ -401,9 +402,9 @@ void Ki2Test::testShow()
 			   "P9 *  *  *  *  *  *  *  *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m29l(Position(4,7), Position(2,9), PBISHOP, 
+    const Move m29l(Square(4,7), Square(2,9), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
-    const Move m29r(Position(1,8), Position(2,9), PBISHOP, 
+    const Move m29r(Square(1,8), Square(2,9), PBISHOP, 
 		    PTYPE_EMPTY, false, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R2+K_K9+K_PBISHOP+K_HIDARI, 
 			 record::ki2::show(m29l, state));
@@ -423,7 +424,7 @@ void Ki2Test::testShow()
 			   "P9 *  *  *  * +OU *  *  *  * \n"
 			   "P+00AL\n"
 			   "-\n").getInitialState());
-    const Move m33ke(Position(3,3), KNIGHT, BLACK);
+    const Move m33ke(Square(3,3), KNIGHT, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R3+K_K3+K_KNIGHT, 
 			 record::ki2::show(m33ke, state));
   }
@@ -441,7 +442,7 @@ void Ki2Test::testShow()
 			   "P+00KA00KY00FU00FU\n"
 			   "P-00FU00FU00FU00FU\n"
 			   "-\n").getInitialState());
-    const Move m57kn(Position(4,5), Position(5,7), 
+    const Move m57kn(Square(4,5), Square(5,7), 
 		     PKNIGHT, PTYPE_EMPTY, true, WHITE);
     CPPUNIT_ASSERT_EQUAL(K_WHITE_SIGN+K_R5+K_K7+K_KNIGHT+K_HIDARI+K_NARU, 
 			 record::ki2::show(m57kn, state));
@@ -460,13 +461,20 @@ void Ki2Test::testShow()
 			   "P+00KA00KA00FU\n"
 			   "P-00GI00FU\n"
 			   "+\n").getInitialState());
-    const Move m52funari(Position(5,3), Position(5,2), 
+    const Move m52funari(Square(5,3), Square(5,2), 
 		     PPAWN, PTYPE_EMPTY, true, BLACK);
     CPPUNIT_ASSERT_EQUAL(K_BLACK_SIGN+K_R5+K_K2+K_PAWN+K_NARU, 
 			 record::ki2::show(m52funari, state));
   }
 }
 
+void Ki2Test::testParseDate()
+{
+  using namespace boost::gregorian;
+  osl::record::ki2::Ki2File ki2("record/ki2_test1.ki2", false);
+  CPPUNIT_ASSERT(!ki2.getRecord().getDate().is_special());
+  CPPUNIT_ASSERT(date(2010, Nov, 13) == ki2.getRecord().getDate());
+}
 
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
